@@ -26,6 +26,7 @@ class VersionedQuery(_Query):
         _Query.__init__(self, client, requestExecutor, queryParameters)
         self._queryParameters = queryParameters
         self.__partition = partitionStrategy
+        
 
     def forMarketData(self, ids: List[int]) -> VersionedQuery:
         """ Set the list of marketdata to be queried.
@@ -138,12 +139,16 @@ class VersionedQuery(_Query):
         self._queryParameters.granularity = granularity
         return self
 
-    def forMUV(self) -> VersionedQuery:
+    def forMUV(self, versionLimit: Optional[str] = None) -> VersionedQuery:
         """ Gets the timeseries of the most updated version of each timepoint of a versioned timeseries.
 
+            Args:
+                versionLimit: string specifying a datetime from which the most updated version should be taken, i.e. MUV as of (versionLimit). Ex.: versionLimit("2021-03-12T14:30:00") 
+
             Returns: 
                 VersionedQuery.
         """
+        self._queryParameters.versionLimit = versionLimit
         self._queryParameters.versionSelectionType = VersionSelectionType.MUV
         return self
 
@@ -209,7 +214,7 @@ class VersionedQuery(_Query):
         """ Gets the specified version of a versioned timeseries.
 
             Args:
-                version: int of a specific version. Ex.: forVersion("2021-03-12T14:30:00")
+                version: string of a specific version. Ex.: forVersion("2021-03-12T14:30:00")
 
             Returns: 
                 VersionedQuery.
@@ -263,16 +268,18 @@ class VersionedQuery(_Query):
         self._queryParameters.fill = _NoFillStrategy()
         return self
 
-    def withFillLatestValue(self, period: str) -> VersionedQuery:
+    def withFillLatestValue(self, period: str, continueToEnd: bool = False) -> VersionedQuery:
         """ Optional filler strategy for the extraction.
 
             Args:
                 period: string of the last period value to fill in case there are missing values. Ex.:   withFillLatestValue("P5D") 
+                continueToEnd: true means the fill extends to the end of the period even if there's no value at the end of the period
+                               false means the fill is only extended to the next valid value
 
             Returns: 
                 VersionedQuery.
         """
-        self._queryParameters.fill = _FillLatestStrategy(period)
+        self._queryParameters.fill = _FillLatestStrategy(period, continueToEnd)
         return self
 
     def withFillCustomValue(self, val: float) -> VersionedQuery:
@@ -324,6 +331,8 @@ class VersionedQuery(_Query):
                 url = url + "&tr=" + qp.transformId
             if not (qp.fill is None):
                 url = url + "&" + qp.fill.getUrlParams()
+            if not (qp.versionLimit is None):
+                url = url + "&versionLimit=" + qp.versionLimit
             urls.append(url)
         return urls
 
